==> dde-control-center_6.0.78.1.tar.xz: BUILD/translations/keyboard_language_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
<context>
    <name>dcc::keyboard::Language</name>
    <message>
        <source>Afar</source>
        <translation>Afar</translation>
    </message>
    <message>
        <source>Afrikaans</source>
        <translation>Africà</translation>
    </message>
    <message>
        <source>አማርኛ</source>
        <translation>አማርኛ</translation>
    </message>
    <message>
        <source>عربية</source>
        <translation>عربية</translation>
    </message>
    <message>
        <source>অসমীয়া</source>
        <translation>অসমীয়া</translation>
    </message>
    <message>
        <source>Asturianu</source>
        <translation>Asturià</translation>
    </message>
    <message>
        <source>Беларуская</source>
        <translation>Беларуская</translation>
    </message>
    <message>
        <source>Biełaruskaja łacinka</source>
        <translation>Biełaruskaja łacinka</translation>
    </message>
    <message>
        <source>Български</source>
        <translation>Български</translation>
    </message>
    <message>
        <source>বাংলা</source>
        <translation>বাংলা</translation>
    </message>
    <message>
        <source>বাংলা (ভারত)</source>
        <translation>বাংলা (ভারত)</translation>
    </message>
    <message>
        <source>བོད་སྐད།</source>
        <translation>བོད་སྐད།</translation>
    </message>
    <message>
        <source>Brezhoneg</source>
        <translation>Brezhoneg</translation>
    </message>
    <message>
        <source>Bosanski</source>
        <translation>Bosanski</translation>
    </message>
    <message>
        <source>Català</source>
        <translation>Català</translation>
    </message>
    <message>
        <source>Qırımtatarca</source>
        <translation>Qırımtatarca</translation>
    </message>
    <message>
        <source>Český</source>
        <translation>Český</translation>
    </message>
    <message>
        <source>Kaszëbsczi</source>
        <translation>Kaszëbsczi</translation>
    </message>
    <message>
        <source>Чăвашла</source>
        <translation>Чăвашла</translation>
    </message>
    <message>
        <source>Cymraeg</source>
        <translation>Cymraeg</translation>
    </message>
    <message>
        <source>Dansk</source>
        <translation>Dansk</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>Deutsch</translation>
    </message>
    <message>
        <source>ཇོང་ཁ</source>
        <translation>ཇོང་ཁ</translation>
    </message>
    <message>
        <source>Ελληνικά</source>
        <translation>Ελληνικά</translation>
    </message>
    <message>
        <source>British English</source>
        <translation>British English</translation>
    </message>
    <message>
        <source>American English</source>
        <translation>American English</translation>
    </message>
    <message>
        <source>Español</source>
        <translation>Espanyol</translation>
    </message>
    <message>
        <source>Eesti</source>
        <translation>Eesti</translation>
    </message>
    <message>
        <source>Euskara</source>
        <translation>Euskara</translation>
    </message>
    <message>
        <source>فارسی</source>
        <translation>فارسی</translation>
    </message>
    <message>
        <source>Suomi</source>
        <translation>Suomi</translation>
    </message>
    <message>
        <source>Føroyskt</source>
        <translation>Føroyskt</translation>
    </message>
    <message>
        <source>Français</source>
        <translation>Français</translation>
    </message>
    <message>
        <source>Frysk</source>
        <translation>Frysk</translation>
    </message>
    <message>
        <source>Gaeilge</source>
        <translation>Gaeilge</translation>
    </message>
    <message>
        <source>Gàidhlig</source>
        <translation>Gàidhlig</translation>
    </message>
    <message>
        <source>Galego</source>
        <translation>Galego</translation>
    </message>
    <message>
        <source>ગુજરાતી </source>
        <translation>ગુજરાતી </translation>
    </message>
    <message>
        <source>Gaelg</source>
        <translation>Gaelg</translation>
    </message>
    <message>
        <source>هَوُسَ</source>
        <translation>هَوُسَ</translation>
    </message>
    <message>
        <source>עברית</source>
        <translation>עברית</translation>
    </message>
    <message>
        <source>हिन्दी</source>
        <translation>हिन्दी</translation>
    </message>
    <message>
        <source>Chhattisgarhi</source>
        <translation>Chhattisgarhi</translation>
    </message>
    <message>
        <source>Hrvatski</source>
        <translation>Hrvatski</translation>
    </message>
    <message>
        <source>Hornjoserbsce</source>
        <translation>Hornjoserbsce</translation>
    </message>
    <message>
        <source>Magyar</source>
        <translation>Magyar</translation>
    </message>
    <message>
        <source>Հայերեն</source>
        <translation>Հայերեն</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonèsia</translation>
    </message>
    <message>
        <source>Iñupiak</source>
        <translation>Iñupiak</translation>
    </message>
    <message>
        <source>Íslenska</source>
        <translation>Íslenska</translation>
    </message>
    <message>
        <source>Italiano</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <source>ᐃᓄᒃᑎᑐᑦ</source>
        <translation>ᐃᓄᒃᑎᑐᑦ</translation>
    </message>
    <message>
        <source>日本語</source>
        <translation>日本語</translation>
    </message>
    <message>
        <source>ქართული</source>
        <translation>ქართული</translation>
    </message>
    <message>
        <source>Қазақша</source>
        <translation>Қазақша</translation>
    </message>
    <message>
        <source>Kalaallisut</source>
        <translation>Kalaallisut</translation>
    </message>
    <message>
        <source>ខ្មែរ</source>
        <translation>ខ្មែរ</translation>
    </message>
    <message>
        <source>ಕನ್ನಡ</source>
        <translation>ಕನ್ನಡ</translation>
    </message>
    <message>
        <source>한국어</source>
        <translation>한국어</translation>
    </message>
    <message>
        <source>कश्मीरी - (كشميري)</source>
        <translation>कश्मीरी - (Caixmir)</translation>
    </message>
    <message>
        <source>Kurdî</source>
        <translation>Kurdî</translation>
    </message>
    <message>
        <source>Kernewek</source>
        <translation>Kernewek</translation>
    </message>
    <message>
        <source>Кыргызча</source>
        <translation>Кыргызча</translation>
    </message>
    <message>
        <source>Lëtzebuergesch</source>
        <translation>Lëtzebuergesch</translation>
    </message>
    <message>
        <source>Limburgs</source>
        <translation>Limburgs</translation>
    </message>
    <message>
        <source>ລາວ</source>
        <translation>ລາວ</translation>
    </message>
    <message>
        <source>Lietuvių</source>
        <translation>Lietuvių</translation>
    </message>
    <message>
        <source>Latviešu</source>
        <translation>Latviešu</translation>
    </message>
    <message>
        <source>Maithili</source>
        <translation>Maithili</translation>
    </message>
    <message>
        <source>Malagasy</source>
        <translation>Malagasy</translation>
    </message>
    <message>
        <source>Ebon</source>
        <translation>Ebon</translation>
    </message>
    <message>
        <source>Māori</source>
        <translation>Māori</translation>
    </message>
    <message>
        <source>Македонски</source>
        <translation>Македонски</translation>
    </message>
    <message>
        <source>മലയാളം</source>
        <translation>മലയാളം</translation>
    </message>
    <message>
        <source>Монгол</source>
        <translation>Монгол</translation>
    </message>
    <message>
        <source>मराठी</source>
        <translation>मराठी</translation>
    </message>
    <message>
        <source>Bahasa Melayu</source>
        <translation>Bahasa Melayu</translation>
    </message>
    <message>
        <source>Malti</source>
        <translation>Malti</translation>
    </message>
    <message>
        <source>Myanmasa</source>
        <translation>Myanmasa</translation>
    </message>
    <message>
        <source>Ekakairũ Naoero</source>
        <translation>Ekakairũ Naoero</translation>
    </message>
    <message>
        <source>Norsk (bokmål)</source>
        <translation>Norsk (bokmål)</translation>
    </message>
    <message>
        <source>Plattdüütsch</source>
        <translation>Plattdüütsch</translation>
    </message>
    <message>
        <source>नेपाली</source>
        <translation>नेपाली</translation>
    </message>
    <message>
        <source>Nederlands</source>
        <translation>Nederlands</translation>
    </message>
    <message>
        <source>Norsk (nynorsk)</source>
        <translation>Norsk (nynorsk)</translation>
    </message>
    <message>
        <source>IsiNdebele</source>
        <translation>IsiNdebele</translation>
    </message>
    <message>
        <source>Sesotho sa Leboa</source>
        <translation>Sesotho sa Leboa</translation>
    </message>
    <message>
        <source>Occitan</source>
        <translation>Occità</translation>
    </message>
    <message>
        <source>Oromoo</source>
        <translation>Oromoo</translation>
    </message>
    <message>
        <source>ଓଡ଼ିଆ</source>
        <translation>ଓଡ଼ିଆ</translation>
    </message>
    <message>
        <source>Иронау</source>
        <translation>Иронау</translation>
    </message>
    <message>
        <source>ਪੰਜਾਬੀ</source>
        <translation>ਪੰਜਾਬੀ</translation>
    </message>
    <message>
        <source>Polski</source>
        <translation>Polski</translation>
    </message>
    <message>
        <source>پښتو</source>
        <translation>پښتو</translation>
    </message>
    <message>
        <source>Português</source>
        <translation>Português</translation>
    </message>
    <message>
        <source>Português do Brasil</source>
        <translation>Português do Brasil</translation>
    </message>
    <message>
        <source>Română</source>
        <translation>Română</translation>
    </message>
    <message>
        <source>Русский</source>
        <translation>Русский</translation>
    </message>
    <message>
        <source>Kinyarwanda</source>
        <translation>Kinyarwanda</translation>
    </message>
    <message>
        <source>संस्कृत</source>
        <translation>संस्कृत</translation>
    </message>
    <message>
        <source>Sardu</source>
        <translation>Sardu</translation>
    </message>
    <message>
        <source>سنڌي</source>
        <translation>سنڌي</translation>
    </message>
    <message>
        <source>Sámegiella</source>
        <translation>Sámegiella</translation>
    </message>
    <message>
        <source>සිංහල</source>
        <translation>සිංහල</translation>
    </message>
    <message>
        <source>Slovenčina</source>
        <translation>Slovenčina</translation>
    </message>
    <message>
        <source>Slovenščina</source>
        <translation>Slovenščina</translation>
    </message>
    <message>
        <source>Soomaaliga</source>
        <translation>Soomaaliga</translation>
    </message>
    <message>
        <source>Shqip</source>
        <translation>Shqip</translation>
    </message>
    <message>
        <source>Српски</source>
        <translation>Српски</translation>
    </message>
    <message>
        <source>srpski (latinica)</source>
        <translation>srpski (latinica)</translation>
    </message>
    <message>
        <source>SiSwati</source>
        <translation>SiSwati</translation>
    </message>
    <message>
        <source>Sesotho</source>
        <translation>Sesotho</translation>
    </message>
    <message>
        <source>Svenska</source>
        <translation>Svenska</translation>
    </message>
    <message>
        <source>Swahili</source>
        <translation>Swahili</translation>
    </message>
    <message>
        <source>தமிழ்</source>
        <translation>தமிழ்</translation>
    </message>
    <message>
        <source>తెలుగు</source>
        <translation>తెలుగు</translation>
    </message>
    <message>
        <source>Тоҷикӣ</source>
        <translation>Тоҷикӣ</translation>
    </message>
    <message>
        <source>ภาษาไทย</source>
        <translation>ภาษาไทย</translation>
    </message>
    <message>
        <source>ትግርኛ</source>
        <translation>ትግርኛ</translation>
    </message>
    <message>
        <source>Türkmen</source>
        <translation>Türkmen</translation>
    </message>
    <message>
        <source>Setswana</source>
        <translation>Setswana</translation>
    </message>
    <message>
        <source>Türkçe</source>
        <translation>Türkçe</translation>
    </message>
    <message>
        <source>Xitsonga</source>
        <translation>Xitsonga</translation>
    </message>
    <message>
        <source>Татарский</source>
        <translation>Татарский</translation>
    </message>
    <message>
        <source>ئۇيغۇرچە</source>
        <translation>ئۇيغۇرچە</translation>
    </message>
    <message>
        <source>Українська</source>
        <translation>Українська</translation>
    </message>
    <message>
        <source>اردو</source>
        <translation>اردو</translation>
    </message>
    <message>
        <source>Oʻzbekcha</source>
        <translation>Oʻzbekcha</translation>
    </message>
    <message>
        <source>Uzbek (Cyrillic)</source>
        <translation>Uzbek (Cyrillic)</translation>
    </message>
    <message>
        <source>Venda</source>
        <translation>Venda</translation>
    </message>
    <message>
        <source>Tiếng Việt</source>
        <translation>Tiếng Việt</translation>
    </message>
    <message>
        <source>Walon</source>
        <translation>Walon</translation>
    </message>
    <message>
        <source>Wolof</source>
        <translation>Wolof</translation>
    </message>
    <message>
        <source>isixhosa</source>
        <translation>isixhosa</translation>
    </message>
    <message>
        <source>ייִדיש</source>
        <translation>ייִדיש</translation>
    </message>
    <message>
        <source>Yorùbá</source>
        <translation>Yorùbá</translation>
    </message>
    <message>
        <source>简体中文</source>
        <translation>简体中文</translation>
    </message>
    <message>
        <source>繁體中文（中國香港）</source>
        <translation>Xinès tradicional (Hong Kong, Xina)</translation>
    </message>
    <message>
        <source>繁體中文（中國臺灣）</source>
        <translation>Xinès tradicional (Taiwan)</translation>
    </message>
    <message>
        <source>isiZulu</source>
        <translation>isiZulu</translation>
    </message>
</context>
</TS>

==> dde-control-center_6.1.26.tar.xz: BUILD/translations/keyboard_language_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>dcc::keyboard::Language</name>
    <message>
        <source>Afar</source>
        <translation>Afar</translation>
    </message>
    <message>
        <source>Afrikaans</source>
        <translation>Africà</translation>
    </message>
    <message>
        <source>አማርኛ</source>
        <translation>አማርኛ</translation>
    </message>
    <message>
        <source>عربية</source>
        <translation>عربية</translation>
    </message>
    <message>
        <source>অসমীয়া</source>
        <translation>অসমীয়া</translation>
    </message>
    <message>
        <source>Asturianu</source>
        <translation>Asturià</translation>
    </message>
    <message>
        <source>Беларуская</source>
        <translation>Беларуская</translation>
    </message>
    <message>
        <source>Biełaruskaja łacinka</source>
        <translation>Biełaruskaja łacinka</translation>
    </message>
    <message>
        <source>Български</source>
        <translation>Български</translation>
    </message>
    <message>
        <source>বাংলা</source>
        <translation>বাংলা</translation>
    </message>
    <message>
        <source>বাংলা (ভারত)</source>
        <translation>বাংলা (ভারত)</translation>
    </message>
    <message>
        <source>བོད་སྐད།</source>
        <translation>བོད་སྐད།</translation>
    </message>
    <message>
        <source>Brezhoneg</source>
        <translation>Brezhoneg</translation>
    </message>
    <message>
        <source>Bosanski</source>
        <translation>Bosanski</translation>
    </message>
    <message>
        <source>Català</source>
        <translation>Català</translation>
    </message>
    <message>
        <source>Qırımtatarca</source>
        <translation>Qırımtatarca</translation>
    </message>
    <message>
        <source>Český</source>
        <translation>Český</translation>
    </message>
    <message>
        <source>Kaszëbsczi</source>
        <translation>Kaszëbsczi</translation>
    </message>
    <message>
        <source>Чăвашла</source>
        <translation>Чăвашла</translation>
    </message>
    <message>
        <source>Cymraeg</source>
        <translation>Cymraeg</translation>
    </message>
    <message>
        <source>Dansk</source>
        <translation>Dansk</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>Deutsch</translation>
    </message>
    <message>
        <source>ཇོང་ཁ</source>
        <translation>ཇོང་ཁ</translation>
    </message>
    <message>
        <source>Ελληνικά</source>
        <translation>Ελληνικά</translation>
    </message>
    <message>
        <source>British English</source>
        <translation>British English</translation>
    </message>
    <message>
        <source>American English</source>
        <translation>American English</translation>
    </message>
    <message>
        <source>Español</source>
        <translation>Espanyol</translation>
    </message>
    <message>
        <source>Eesti</source>
        <translation>Eesti</translation>
    </message>
    <message>
        <source>Euskara</source>
        <translation>Euskara</translation>
    </message>
    <message>
        <source>فارسی</source>
        <translation>فارسی</translation>
    </message>
    <message>
        <source>Suomi</source>
        <translation>Suomi</translation>
    </message>
    <message>
        <source>Føroyskt</source>
        <translation>Føroyskt</translation>
    </message>
    <message>
        <source>Français</source>
        <translation>Français</translation>
    </message>
    <message>
        <source>Frysk</source>
        <translation>Frysk</translation>
    </message>
    <message>
        <source>Gaeilge</source>
        <translation>Gaeilge</translation>
    </message>
    <message>
        <source>Gàidhlig</source>
        <translation>Gàidhlig</translation>
    </message>
    <message>
        <source>Galego</source>
        <translation>Galego</translation>
    </message>
    <message>
        <source>ગુજરાતી </source>
        <translation>ગુજરાતી </translation>
    </message>
    <message>
        <source>Gaelg</source>
        <translation>Gaelg</translation>
    </message>
    <message>
        <source>هَوُسَ</source>
        <translation>هَوُسَ</translation>
    </message>
    <message>
        <source>עברית</source>
        <translation>עברית</translation>
    </message>
    <message>
        <source>हिन्दी</source>
        <translation>हिन्दी</translation>
    </message>
    <message>
        <source>Chhattisgarhi</source>
        <translation>Chhattisgarhi</translation>
    </message>
    <message>
        <source>Hrvatski</source>
        <translation>Hrvatski</translation>
    </message>
    <message>
        <source>Hornjoserbsce</source>
        <translation>Hornjoserbsce</translation>
    </message>
    <message>
        <source>Magyar</source>
        <translation>Magyar</translation>
    </message>
    <message>
        <source>Հայերեն</source>
        <translation>Հայերեն</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonèsia</translation>
    </message>
    <message>
        <source>Iñupiak</source>
        <translation>Iñupiak</translation>
    </message>
    <message>
        <source>Íslenska</source>
        <translation>Íslenska</translation>
    </message>
    <message>
        <source>Italiano</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <source>ᐃᓄᒃᑎᑐᑦ</source>
        <translation>ᐃᓄᒃᑎᑐᑦ</translation>
    </message>
    <message>
        <source>日本語</source>
        <translation>日本語</translation>
    </message>
    <message>
        <source>ქართული</source>
        <translation>ქართული</translation>
    </message>
    <message>
        <source>Қазақша</source>
        <translation>Қазақша</translation>
    </message>
    <message>
        <source>Kalaallisut</source>
        <translation>Kalaallisut</translation>
    </message>
    <message>
        <source>ខ្មែរ</source>
        <translation>ខ្មែរ</translation>
    </message>
    <message>
        <source>ಕನ್ನಡ</source>
        <translation>ಕನ್ನಡ</translation>
    </message>
    <message>
        <source>한국어</source>
        <translation>한국어</translation>
    </message>
    <message>
        <source>कश्मीरी - (كشميري)</source>
        <translation>कश्मीरी - (Caixmir)</translation>
    </message>
    <message>
        <source>Kurdî</source>
        <translation>Kurdî</translation>
    </message>
    <message>
        <source>Kernewek</source>
        <translation>Kernewek</translation>
    </message>
    <message>
        <source>Кыргызча</source>
        <translation>Кыргызча</translation>
    </message>
    <message>
        <source>Lëtzebuergesch</source>
        <translation>Lëtzebuergesch</translation>
    </message>
    <message>
        <source>Limburgs</source>
        <translation>Limburgs</translation>
    </message>
    <message>
        <source>ລາວ</source>
        <translation>ລາວ</translation>
    </message>
    <message>
        <source>Lietuvių</source>
        <translation>Lietuvių</translation>
    </message>
    <message>
        <source>Latviešu</source>
        <translation>Latviešu</translation>
    </message>
    <message>
        <source>Maithili</source>
        <translation>Maithili</translation>
    </message>
    <message>
        <source>Malagasy</source>
        <translation>Malagasy</translation>
    </message>
    <message>
        <source>Ebon</source>
        <translation>Ebon</translation>
    </message>
    <message>
        <source>Māori</source>
        <translation>Māori</translation>
    </message>
    <message>
        <source>Македонски</source>
        <translation>Македонски</translation>
    </message>
    <message>
        <source>മലയാളം</source>
        <translation>മലയാളം</translation>
    </message>
    <message>
        <source>Монгол</source>
        <translation>Монгол</translation>
    </message>
    <message>
        <source>मराठी</source>
        <translation>मराठी</translation>
    </message>
    <message>
        <source>Bahasa Melayu</source>
        <translation>Bahasa Melayu</translation>
    </message>
    <message>
        <source>Malti</source>
        <translation>Malti</translation>
    </message>
    <message>
        <source>Myanmasa</source>
        <translation>Myanmasa</translation>
    </message>
    <message>
        <source>Ekakairũ Naoero</source>
        <translation>Ekakairũ Naoero</translation>
    </message>
    <message>
        <source>Norsk (bokmål)</source>
        <translation>Norsk (bokmål)</translation>
    </message>
    <message>
        <source>Plattdüütsch</source>
        <translation>Plattdüütsch</translation>
    </message>
    <message>
        <source>नेपाली</source>
        <translation>नेपाली</translation>
    </message>
    <message>
        <source>Nederlands</source>
        <translation>Nederlands</translation>
    </message>
    <message>
        <source>Norsk (nynorsk)</source>
        <translation>Norsk (nynorsk)</translation>
    </message>
    <message>
        <source>IsiNdebele</source>
        <translation>IsiNdebele</translation>
    </message>
    <message>
        <source>Sesotho sa Leboa</source>
        <translation>Sesotho sa Leboa</translation>
    </message>
    <message>
        <source>Occitan</source>
        <translation>Occità</translation>
    </message>
    <message>
        <source>Oromoo</source>
        <translation>Oromoo</translation>
    </message>
    <message>
        <source>ଓଡ଼ିଆ</source>
        <translation>ଓଡ଼ିଆ</translation>
    </message>
    <message>
        <source>Иронау</source>
        <translation>Иронау</translation>
    </message>
    <message>
        <source>ਪੰਜਾਬੀ</source>
        <translation>ਪੰਜਾਬੀ</translation>
    </message>
    <message>
        <source>Polski</source>
        <translation>Polski</translation>
    </message>
    <message>
        <source>پښتو</source>
        <translation>پښتو</translation>
    </message>
    <message>
        <source>Português</source>
        <translation>Português</translation>
    </message>
    <message>
        <source>Português do Brasil</source>
        <translation>Português do Brasil</translation>
    </message>
    <message>
        <source>Română</source>
        <translation>Română</translation>
    </message>
    <message>
        <source>Русский</source>
        <translation>Русский</translation>
    </message>
    <message>
        <source>Kinyarwanda</source>
        <translation>Kinyarwanda</translation>
    </message>
    <message>
        <source>संस्कृत</source>
        <translation>संस्कृत</translation>
    </message>
    <message>
        <source>Sardu</source>
        <translation>Sardu</translation>
    </message>
    <message>
        <source>سنڌي</source>
        <translation>سنڌي</translation>
    </message>
    <message>
        <source>Sámegiella</source>
        <translation>Sámegiella</translation>
    </message>
    <message>
        <source>සිංහල</source>
        <translation>සිංහල</translation>
    </message>
    <message>
        <source>Slovenčina</source>
        <translation>Slovenčina</translation>
    </message>
    <message>
        <source>Slovenščina</source>
        <translation>Slovenščina</translation>
    </message>
    <message>
        <source>Soomaaliga</source>
        <translation>Soomaaliga</translation>
    </message>
    <message>
        <source>Shqip</source>
        <translation>Shqip</translation>
    </message>
    <message>
        <source>Српски</source>
        <translation>Српски</translation>
    </message>
    <message>
        <source>srpski (latinica)</source>
        <translation>srpski (latinica)</translation>
    </message>
    <message>
        <source>SiSwati</source>
        <translation>SiSwati</translation>
    </message>
    <message>
        <source>Sesotho</source>
        <translation>Sesotho</translation>
    </message>
    <message>
        <source>Svenska</source>
        <translation>Svenska</translation>
    </message>
    <message>
        <source>Swahili</source>
        <translation>Swahili</translation>
    </message>
    <message>
        <source>தமிழ்</source>
        <translation>தமிழ்</translation>
    </message>
    <message>
        <source>తెలుగు</source>
        <translation>తెలుగు</translation>
    </message>
    <message>
        <source>Тоҷикӣ</source>
        <translation>Тоҷикӣ</translation>
    </message>
    <message>
        <source>ภาษาไทย</source>
        <translation>ภาษาไทย</translation>
    </message>
    <message>
        <source>ትግርኛ</source>
        <translation>ትግርኛ</translation>
    </message>
    <message>
        <source>Türkmen</source>
        <translation>Türkmen</translation>
    </message>
    <message>
        <source>Setswana</source>
        <translation>Setswana</translation>
    </message>
    <message>
        <source>Türkçe</source>
        <translation>Türkçe</translation>
    </message>
    <message>
        <source>Xitsonga</source>
        <translation>Xitsonga</translation>
    </message>
    <message>
        <source>Татарский</source>
        <translation>Татарский</translation>
    </message>
    <message>
        <source>ئۇيغۇرچە</source>
        <translation>ئۇيغۇرچە</translation>
    </message>
    <message>
        <source>Українська</source>
        <translation>Українська</translation>
    </message>
    <message>
        <source>اردو</source>
        <translation>اردو</translation>
    </message>
    <message>
        <source>Oʻzbekcha</source>
        <translation>Oʻzbekcha</translation>
    </message>
    <message>
        <source>Uzbek (Cyrillic)</source>
        <translation>Uzbek (Cyrillic)</translation>
    </message>
    <message>
        <source>Venda</source>
        <translation>Venda</translation>
    </message>
    <message>
        <source>Tiếng Việt</source>
        <translation>Tiếng Việt</translation>
    </message>
    <message>
        <source>Walon</source>
        <translation>Walon</translation>
    </message>
    <message>
        <source>Wolof</source>
        <translation>Wolof</translation>
    </message>
    <message>
        <source>isixhosa</source>
        <translation>isixhosa</translation>
    </message>
    <message>
        <source>ייִדיש</source>
        <translation>ייִדיש</translation>
    </message>
    <message>
        <source>Yorùbá</source>
        <translation>Yorùbá</translation>
    </message>
    <message>
        <source>简体中文</source>
        <translation>简体中文</translation>
    </message>
    <message>
        <source>繁體中文(中國香港)</source>
        <translation>Xinès tradicional (Hong Kong, Xina)</translation>
    </message>
    <message>
        <source>繁體中文</source>
        <translation>xinès tradicional</translation>
    </message>
    <message>
        <source>isiZulu</source>
        <translation>isiZulu</translation>
    </message>
    <message>
        <source>Català (Valencià)</source>
        <translation>Català (Valencià)</translation>
    </message>
    <message>
        <source>Esperanto</source>
        <translation>Esperanto</translation>
    </message>
    <message>
        <source>Interlingua</source>
        <translation>Interlingua</translation>
    </message>
    <message>
        <source>Kabyle</source>
        <translation>Kabyle</translation>
    </message>
    <message>
        <source>Azerbaijani</source>
        <translation>Azerbaijani</translation>
    </message>
    <message>
        <source>Filipino</source>
        <translation>Filipino</translation>
    </message>
</context>
</TS>
